==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcNxNshTtlCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcNxNshTtlCaseBuilder} instances.
 *
 * @see SrcNxNshTtlCaseBuilder
 *
 */
public class SrcNxNshTtlCaseBuilder implements Builder<SrcNxNshTtlCase> {

    private Boolean _nxNshTtl;


    Map<Class<? extends Augmentation<SrcNxNshTtlCase>>, Augmentation<SrcNxNshTtlCase>> augmentation = Collections.emptyMap();

    public SrcNxNshTtlCaseBuilder() {
    }
    public SrcNxNshTtlCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping arg) {
        this._nxNshTtl = arg.isNxNshTtl();
    }

    public SrcNxNshTtlCaseBuilder(SrcNxNshTtlCase base) {
        this._nxNshTtl = base.isNxNshTtl();
        if (base instanceof SrcNxNshTtlCaseImpl) {
            SrcNxNshTtlCaseImpl impl = (SrcNxNshTtlCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcNxNshTtlCase>>, Augmentation<SrcNxNshTtlCase>> aug =((AugmentationHolder<SrcNxNshTtlCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping) {
            this._nxNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping)arg).isNxNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping]");
    }

    public Boolean isNxNshTtl() {
        return _nxNshTtl;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<SrcNxNshTtlCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcNxNshTtlCaseBuilder setNxNshTtl(final Boolean value) {
        this._nxNshTtl = value;
        return this;
    }
    
    public SrcNxNshTtlCaseBuilder addAugmentation(Class<? extends Augmentation<SrcNxNshTtlCase>> augmentationType, Augmentation<SrcNxNshTtlCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcNxNshTtlCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcNxNshTtlCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcNxNshTtlCase build() {
        return new SrcNxNshTtlCaseImpl(this);
    }

    private static final class SrcNxNshTtlCaseImpl implements SrcNxNshTtlCase {
    
        private final Boolean _nxNshTtl;
    
        private Map<Class<? extends Augmentation<SrcNxNshTtlCase>>, Augmentation<SrcNxNshTtlCase>> augmentation = Collections.emptyMap();
    
        SrcNxNshTtlCaseImpl(SrcNxNshTtlCaseBuilder base) {
            this._nxNshTtl = base.isNxNshTtl();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcNxNshTtlCase> getImplementedInterface() {
            return SrcNxNshTtlCase.class;
        }
    
        @Override
        public Boolean isNxNshTtl() {
            return _nxNshTtl;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<SrcNxNshTtlCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxNshTtl);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcNxNshTtlCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcNxNshTtlCase other = (SrcNxNshTtlCase)obj;
            if (!Objects.equals(_nxNshTtl, other.isNxNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcNxNshTtlCaseImpl otherImpl = (SrcNxNshTtlCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcNxNshTtlCase>>, Augmentation<SrcNxNshTtlCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcNxNshTtlCase");
            CodeHelpers.appendValue(helper, "_nxNshTtl", _nxNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcNxNshTtlCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcNxNshTtlCaseBuilder} instances.
 *
 * @see SrcNxNshTtlCaseBuilder
 *
 */
public class SrcNxNshTtlCaseBuilder implements Builder<SrcNxNshTtlCase> {

    private Boolean _nxNshTtl;


    Map<Class<? extends Augmentation<SrcNxNshTtlCase>>, Augmentation<SrcNxNshTtlCase>> augmentation = Collections.emptyMap();

    public SrcNxNshTtlCaseBuilder() {
    }
    public SrcNxNshTtlCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping arg) {
        this._nxNshTtl = arg.isNxNshTtl();
    }

    public SrcNxNshTtlCaseBuilder(SrcNxNshTtlCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcNxNshTtlCase>>, Augmentation<SrcNxNshTtlCase>> aug =((AugmentationHolder<SrcNxNshTtlCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxNshTtl = base.isNxNshTtl();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping) {
            this._nxNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping)arg).isNxNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshTtlGrouping]");
    }

    public Boolean isNxNshTtl() {
        return _nxNshTtl;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<SrcNxNshTtlCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcNxNshTtlCaseBuilder setNxNshTtl(final Boolean value) {
        this._nxNshTtl = value;
        return this;
    }
    
    public SrcNxNshTtlCaseBuilder addAugmentation(Class<? extends Augmentation<SrcNxNshTtlCase>> augmentationType, Augmentation<SrcNxNshTtlCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcNxNshTtlCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcNxNshTtlCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcNxNshTtlCase build() {
        return new SrcNxNshTtlCaseImpl(this);
    }

    private static final class SrcNxNshTtlCaseImpl
        extends AbstractAugmentable<SrcNxNshTtlCase>
        implements SrcNxNshTtlCase {
    
        private final Boolean _nxNshTtl;
    
        SrcNxNshTtlCaseImpl(SrcNxNshTtlCaseBuilder base) {
            super(base.augmentation);
            this._nxNshTtl = base.isNxNshTtl();
        }
    
        @Override
        public Class<SrcNxNshTtlCase> getImplementedInterface() {
            return SrcNxNshTtlCase.class;
        }
    
        @Override
        public Boolean isNxNshTtl() {
            return _nxNshTtl;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxNshTtl);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcNxNshTtlCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcNxNshTtlCase other = (SrcNxNshTtlCase)obj;
            if (!Objects.equals(_nxNshTtl, other.isNxNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcNxNshTtlCaseImpl otherImpl = (SrcNxNshTtlCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcNxNshTtlCase>>, Augmentation<SrcNxNshTtlCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcNxNshTtlCase");
            CodeHelpers.appendValue(helper, "_nxNshTtl", _nxNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
